﻿using System;
using System.Collections.Generic;
using System.Linq;
using System.Web;
using System.Web.UI.WebControls;
using System.ComponentModel;

/// <summary>
/// Vylepšená komponenta SqlDataSource, která po datové operaci provádí redirect
/// </summary>
public class RedirectingSqlDataSource:SqlDataSource
{
    /// <summary>
    /// Určuje, zda-li se má po provedení datové operace přesměrovat na adresu, na které se právě nacházíme
    /// </summary>
	[Category("Behavior"), DefaultValue(false)]
    public bool RedirectAfterDataOperation
    {
        get { return (bool)(this.ViewState["RedirectAfterDataOperation"] ?? false); }
        set { this.ViewState["RedirectAfterDataOperation"] = value; }
	}
    /// <summary>
    /// Pokud je tato funkce zapnutá, provede přesměrování
    /// </summary>
    private void RedirectEnabled(object sender, SqlDataSourceStatusEventArgs e)
    {
        if (this.RedirectAfterDataOperation)
            Page.Response.Redirect(Page.Request.RawUrl);
    }
    /// <summary>
    /// Nastavit obsluhu událostí Inserted, Updated a Deleted
    /// </summary>
    protected override void OnLoad(EventArgs e)
    {
        base.OnLoad(e);
        this.Inserted += new SqlDataSourceStatusEventHandler(RedirectEnabled);
        this.Updated += new SqlDataSourceStatusEventHandler(RedirectEnabled);
        this.Deleted += new SqlDataSourceStatusEventHandler(RedirectEnabled);
    }
}